# remote for neovim

Inspired by [mhinz/neovim-remote](https://github.com/mhinz/neovim-remote). 
This project works on Windows as well.

## usage
`r4n [filename]`

## installation
```
pip install remote4neovim
```

## dependencies
- psutil
